from . import formatters


SUPPORTED_CONTENT_TYPES = (
    'audio/L16',
    'audio/x-flac',
    'audio/x-wav',
    'audio/ogg',
    'audio/basic'
)

SUPPORTED_AUDIO_MODELS = (
    'ar-AR_BroadbandModel',
    'en-UK_BroadbandModel',
    'en-UK_NarrowbandModel',
    'en-US_BroadbandModel',
    'en-US_NarrowbandModel',
    'es-ES_BroadbandModel',
    'es-ES_NarrowbandModel',
    'fr-FR_BroadbandModel',
    'ja-JP_BroadbandModel',
    'ja-JP_NarrowbandModel',
    'pt-BR_BroadbandModel',
    'pt-BR_NarrowbandModel',
    'zh-CN_BroadbandModel',
    'zh-CN_NarrowbandModel'
)
